from drf_simple_access_key.settings import simple_access_key_settings


__all__ = [
    'SimpleAccessKey'
]


class SimpleAccessKey(object):
    """
    Allow access if a valid authorisation token was part of the request headers. The authorization
    data consists of a scheme ("Bearer" in this case) and the actual key. If no valid keys are
    configured in the application settings, this permission class will grant access.
    """

    def has_permission(self, request, view):
        """
        Grants permission if the given authorization key is within the configured allowed keys. Also grants
        permission if no allowed keys are configured.
        """
        settings = simple_access_key_settings()
        allowed_keys = settings.AUTHORIZATION_KEYS
        request_key = request.headers.get(
            settings.HTTP_AUTHORIZATION_HEADER
        )

        if not allowed_keys:
            return True

        try:
            key_schema, key = request_key.split(" ", maxsplit=1)
            key_schema, key = key_schema.strip().lower(), key.strip()

            return key_schema == settings.HTTP_AUTHORIZATION_SCHEME and key in allowed_keys
        except (AttributeError, ValueError,):
            return False

    def has_object_permission(self, request, view, obj):
        """
        This permission class has no special implementation of per-object permissions, so the result
        will be the same as the `has_permission` method.
        """
        return self.has_permission(request, view)



from django.conf import settings
from rest_framework.settings import APISettings


__all__ = [
    'simple_access_key_settings'
]


SIMPLE_ACCESS_KEY_SETTINGS = {
    'HTTP_AUTHORIZATION_HEADER': 'x-authorization',
    'HTTP_AUTHORIZATION_SCHEME': 'bearer',
    'AUTHORIZATION_KEYS': [],
}


def simple_access_key_settings():
    return APISettings(
        user_settings=getattr(settings, 'SIMPLE_ACCESS_KEY_SETTINGS', {}),
        defaults=SIMPLE_ACCESS_KEY_SETTINGS,
    )



import os

from setuptools import find_packages, setup

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as fh:
    readme = fh.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='drf-simple-access-key',
    version=os.getenv('PACKAGE_VERSION', '0.0.0').replace('refs/tags/', ''),
    packages=find_packages(),
    include_package_data=True,
    license='MIT',
    description='A library that provides a simple token authorization for Django REST framework.',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/anexia-it/drf-simple-access-key',
    author='Harald Nezbeda',
    author_email='HNezbeda@anexia-it.com',
    install_requires=[
        'django>=2.2',
        'djangorestframework>=3.10',
    ],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Framework :: Django',
        'Framework :: Django :: 2.2',
        'Framework :: Django :: 3.1',
        'Framework :: Django :: 3.2',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
)
